@@ -7,20 +7,16 @@ be accessed from there.
 """
 
 import functools
-import sys
 
 from astropy.utils.decorators import deprecated
 
-__all__ = ["override__dir__", "PYTHON_LT_3_11"]
-
-PYTHON_LT_3_11 = sys.version_info < (3, 11)
+__all__ = ["override__dir__"]
 
 
 @deprecated(
-    since="v5.2",
-    message=(
-        "http://bugs.python.org/issue12166 is resolved. See docstring for alternatives."
-    ),
+    since="5.2",
+    message="http://bugs.python.org/issue12166 is resolved, {alternative}.",
+    alternative="use ``sorted(super().__dir__() + ...)`` instead",
 )
 def override__dir__(f):
     """
@@ -29,9 +25,6 @@ def override__dir__(f):
     automatically, and all the wrapped function needs to do is return a list of
     the "special" members that wouldn't be found by the normal Python means.
 
-    .. deprecated:: v5.2
-        Use ``sorted(super().__dir__() + ...)`` instead.
-
     Example
     -------
 
